@@ -1,7 +1,9 @@
 from com import FileInspector, msgs
 from mediabox import tagreader
+from utils import logging
 
 import os
+import time
 
 
 class AudioInspector(FileInspector):
@@ -21,6 +23,8 @@ class AudioInspector(FileInspector):
         
     def inspect(self, entry):   
         
+        profile_now = time.time()
+        
         path = entry["File.Path"]
         basename = os.path.basename(path)
         dirname = os.path.dirname(path)
@@ -42,3 +46,6 @@ class AudioInspector(FileInspector):
             trackno = 0
         entry["Audio.Tracknumber"] = trackno
 
+        logging.profile(profile_now, "[audioinspector] inspected file: %s",
+                        path)
+
