@@ -87,11 +87,6 @@ Gets emitted when a folder gets visited by the user.
 @param folder: file object representing the folder
 """
 
-def CORE_SVC_LIST_PATH(path): pass
-"""
-@deprecated: do not use; it will be removed
-"""
-
 def CORE_SVC_GET_FILE(path): pass
 """
 Looks up the file object for the given full path string.
@@ -121,26 +116,6 @@ Sets the title bar info text.
 @param info: info text
 """
 
-def CORE_ACT_SET_TOOLBAR(toolbar_set): pass
-"""
-Sets the toolbar widgets.
-@deprecated: this is not used anymore
-
-@param toolbar_set: list of widgets
-"""
-
-def CORE_ACT_SEARCH_ITEM(search_term): pass
-"""
-Instructs viewers to search for the given search term.
-
-@param search_term: search term
-"""
-
-def CORE_EV_SEARCH_CLOSED(): pass
-"""
-Gets emitted when the search mode is left.
-"""
-
 def CORE_EV_THEME_CHANGED(): pass
 """
 Gets emitted when the theme has changed.
@@ -172,6 +147,15 @@ Instructs the current media player to load the given file.
 @param f: file object to load
 """
 
+def MEDIA_ACT_CHANGE_PLAY_FOLDER(f): pass
+"""
+Instructs the media player to change the play folder to the given folder.
+This must be called after loading media.
+@since: 2010.09.20
+
+@param: folder to change to
+"""
+
 def MEDIA_ACT_PLAY(): pass
 """
 Instructs the current media player to play.
@@ -610,10 +594,3 @@ def HWKEY_EV_F12(): pass
 F12 hardware key.
 """
 
-def HWKEY_EV_KEY(key): pass
-"""
-Any letter hardware key.
-
-@param key: key code
-"""
-
