@@ -139,13 +139,16 @@ class LyricsCaster(Component):
         """
         
         try:
-            data = self.__decode(open(lrc_path).read())
-            lines = data.splitlines()
+            data = open(lrc_path).read()
+            #data = self.__decode(open(lrc_path).read())
+            lines = [ l for l in data.splitlines() if l.startswith("[") ]
         except:
             logging.error("error loading lyrics file '%s'\n%s",
                           lrc_path, logging.stacktrace())
             lines = []
-            
+        
+        lines = self.__decode("\n".join(lines)).splitlines()
+        
         for line in lines:
             self.__parse_line(line)
         self.__lyrics.sort(lambda a,b:cmp(a[0],b[0]))
@@ -228,9 +231,11 @@ class LyricsCaster(Component):
             idx2 = line.find("]", idx1)
             
             if (idx1 == -1 or idx2 == -1): break
-                           
-            timetags.append(line[idx1 + 1:idx2])
-            text = line[idx2 + 1:]
+
+            tag = line[idx1 + 1:idx2]
+            if (self.__is_valid_timetag(tag)):
+                timetags.append(tag)
+                text = line[idx2 + 1:]
             
             # look for multiple time tags
             if (len(line) > idx2 + 1 and line[idx2 + 1] == "["):
@@ -278,8 +283,21 @@ class LyricsCaster(Component):
             self.__lyrics.append((timestamp, line, pos1, pos2))
             pos1 = pos2
         #end for
+
+
+    def __is_valid_timetag(self, tag):
+        """
+        Validates the given time tag and returns whether it is valid or not.
+        """
         
-                
+        # just a quick inaccurate check
+        invalid_chars = [ c for c in tag
+                          if not c.isdigit() and not c in (":", ".") ]
+        if (invalid_chars):
+            return False
+        else:
+            return True
+
                 
     def __make_timestamp(self, t):
         """
