@@ -69,6 +69,10 @@ class PlayerWindow(Dialog):
         if (platforms.MAEMO5):
             self.set_menu_item("fmtx", "FM Transmitter", True,
                                self.__on_menu_fmtx)
+
+        self.set_menu_item("add-bookmark", "Mark Current Position", True,
+                           self.__on_menu_add_bookmark)
+
         #self.set_menu_item("info", "About", True,
         #                   self.__on_menu_info)
 
@@ -91,6 +95,12 @@ class PlayerWindow(Dialog):
             mb_config.set_shuffle_mode(mb_config.SHUFFLE_MODE_ONE)
 
 
+    def __on_menu_add_bookmark(self):
+    
+        if (self.__current_player):
+            self.__current_player.set_bookmark()
+            
+
     def __on_menu_select_output(self):
     
         self.emit_message(msgs.MEDIA_ACT_SELECT_OUTPUT, None)
