@@ -3,14 +3,12 @@ from com import msgs
 from io import Downloader
 from utils import logging
 from utils import urlquote
+from utils.BeautifulSoup import BeautifulSoup
 from theme import theme
 
-from xml.etree import ElementTree
-from cStringIO import StringIO
 
-
-#_SHOUTCAST_BASE = "http://www.shoutcast.com"
-_SHOUTCAST_BASE = "http://yp.shoutcast.com"
+_SHOUTCAST_BASE = "http://www.shoutcast.com"
+#_SHOUTCAST_BASE = "http://yp.shoutcast.com"
 
 
 
@@ -66,11 +64,12 @@ class ShoutcastDirectory(Device):
     def __make_genre(self, genre):
 
         f = File(self)    
-        f.name = genre
+        f.name = genre.replace("&amp;", "&")
         f.path = "/" + urlquote.quote(genre, "")
         f.mimetype = f.DIRECTORY
         f.icon = theme.shoutcast_folder.get_path()
         f.folder_flags = f.ITEMS_ENQUEUEABLE
+        print f.name, f.path
 
         return f
 
@@ -78,7 +77,7 @@ class ShoutcastDirectory(Device):
     def __make_station(self, s):
     
         try:
-            name, bitrate, mimetype, location, genre = self.__decode_station(s)
+            prefix, name, bitrate, mimetype, location, genre = File.unpack_path(s)
         except:
             logging.error("error decoding iradio path: %s\n%s",
                             path, logging.stacktrace())
@@ -88,7 +87,7 @@ class ShoutcastDirectory(Device):
         f.name = name
         f.info = "Bitrate: %s kb" % bitrate
         f.resource = location
-        f.path = "/" + urlquote.quote(genre, "") + "/" + s
+        f.path = s
         f.mimetype = mimetype
         f.icon = theme.shoutcast_station.get_path()
         
@@ -99,7 +98,7 @@ class ShoutcastDirectory(Device):
 
         parts = [ p for p in path.split("/") if p ]
         len_parts = len(parts)
-        
+
         f = None
         if (len_parts == 0):
             # root folder
@@ -114,6 +113,7 @@ class ShoutcastDirectory(Device):
     
         elif (len_parts == 1):
             genre = urlquote.unquote(parts[0])
+            print "GENRE", genre
             f = self.__make_genre(genre)
     
         elif (len_parts == 2):
@@ -175,36 +175,43 @@ class ShoutcastDirectory(Device):
         if (len_parts == 0):
             # list genres
             if (not self.__genres):
-                dl = Downloader(_SHOUTCAST_BASE + "/sbin/newxml.phtml",
+                dl = Downloader(_SHOUTCAST_BASE + "/",
                                 on_load_genres, [""])
             else:
                 list_genres()
 
         elif (len_parts == 1):
             # list stations
-            genre = parts[0]
-            dl = Downloader(_SHOUTCAST_BASE + "/sbin/newxml.phtml?genre=%s" % genre,
+            genre = urlquote.unquote(parts[0])
+            dl = Downloader(_SHOUTCAST_BASE + "/radio/" + genre,
                             on_load_stations, [""], genre)
         
 
 
     def __parse_genres(self, data):
         """
-        Parses the XML list of genres.
+        Parses the list of genres.
         """
-
+        
+        self.call_service(msgs.UI_ACT_SHOW_INFO,
+                          "SHOUTcast made it illegal for free software to access\n" \
+                          "their full directory.\n" \
+                          "You will only get the Top 10 stations listed per genre.")
+        
         genres = []
-        try:
-            dtree = ElementTree.parse(StringIO(data))
-            for i in dtree.getiterator():
-                if i.tag == "genre":
-                    for j,n in i.items():
-                        if j == "name":
-                            genres.append(n)
-        except:
-            #self.call_service(msgs.UI_ACT_SHOW_INFO,
-            #                  "An error occured while loading the list of genres.\n" \
-            #                  "Check your internet connection and try again.")
+        soup = BeautifulSoup(data)
+        radiopicker = soup.find("div", {"id": "radiopicker"})
+        #print radiopicker
+        if (radiopicker):
+            for genre_tag in radiopicker.findAll("li", {"class": "prigen"}):
+                #print genre_tag
+                name = genre_tag.a.contents[0]
+                name = name.replace("&amp;", "&")
+                genres.append(name)
+            #end for
+        #end if
+    
+        if (not genres):
             self.__current_folder.message = "genre list not available"
             logging.error("SHOUTcast genre listing download failed:\n%s",
                           logging.stacktrace())
@@ -215,46 +222,53 @@ class ShoutcastDirectory(Device):
 
     def __parse_stations(self, data, genre):
         """
-        Parses the XML list of stations.
+        Parses the list of stations.
         """
 
         stations = []
-        try:
-            dtree = ElementTree.parse(StringIO(data))
-            for i in dtree.getiterator():
-                if i.tag == "station":
-                    # build station object
-                    station = File(self)
-                    bitrate = "-"
-                    now_playing = "-"
-                    
-                    for j,n in i.items():
-                        if j == "name":
-                            station.name = n
-                        elif j == "ct":
-                            now_playing = n
-                        elif j == "id":
-                            station.resource = _SHOUTCAST_BASE + "/sbin/shoutcast-playlist.pls?rn=%s&file=filename.pls" % n
-                        elif j == "br":
-                            bitrate = n
-                        elif j == "mt":
-                            station.mimetype = n
+        soup = BeautifulSoup(data)
+        resulttable = soup.find("div", {"id": "resulttable"})
+        if (resulttable):
+            for entry in resulttable.findAll("div", {"class": "dirlist"}):
+                #print entry
+                station = File(self)
+                a_tag = entry.find("a", {"class": "playbutton playimage"})
+                playing_tag = entry.find("div", {"class": "playingtext"})
+                bitrate_tag = entry.find("div", {"class": "dirbitrate"})
+                type_tag = entry.find("div", {"class": "dirtype"})
+                
+                if (not a_tag or
+                    not playing_tag or
+                    not bitrate_tag or
+                    not type_tag): continue
+                
+                station.resource = a_tag["href"]
+                station.name = a_tag["title"]
+                now_playing = playing_tag["title"]
+                bitrate = bitrate_tag.contents[0].strip()
 
-                    station.path = "/" + genre + "/" + \
-                                   self.__encode_station(station.name,
-                                                         bitrate,
-                                                         station.mimetype,
-                                                         station.resource,
-                                                         genre)
-                    station.info = "Bitrate: %s kb\n" \
-                                   "Now playing: %s" % (bitrate, now_playing)
-                    station.icon = theme.shoutcast_station.get_path()
-                    stations.append(station)
-
-        except:
-            #self.call_service(msgs.UI_ACT_SHOW_INFO,
-            #                  "An error occured while loading the list of stations.\n" \
-            #                  "Check your internet connection and try again.")
+                typename = type_tag.contents[0].strip()
+                if (typename == "MP3"):
+                    station.mimetype = "audio/mpeg"
+                elif (typename == "AAC+"):
+                    station.mimetype = "audio/mp4"
+                else:
+                    station.mimetype = "audio/x-unknown"
+                
+                station.path = File.pack_path("/" + urlquote.quote(genre, ""),
+                                              station.name,
+                                              bitrate,
+                                              station.mimetype,
+                                              station.resource,
+                                              genre)
+                station.info = "Bitrate: %s kb\n" \
+                               "Now playing: %s" % (bitrate, now_playing)
+                station.icon = theme.shoutcast_station.get_path()
+                stations.append(station)
+            #end for
+        #end if
+        
+        if (not stations):
             self.__current_folder.message = "station list not available"
             logging.error("SHOUTcast station listing download failed\n%s",
                           logging.stacktrace())
@@ -262,16 +276,3 @@ class ShoutcastDirectory(Device):
         stations.sort()
         return stations
 
-
-
-    def __encode_station(self, name, bitrate, mimetype, resource, genre):
-    
-        s = "\t\t\t".join([name, bitrate, mimetype, resource, genre])
-        return urlquote.quote(s, "")
-
-
-    def __decode_station(self, s):
-    
-        data = urlquote.unquote(s)
-        name, bitrate, mimetype, resource, genre = data.split("\t\t\t")
-        return (name, bitrate, mimetype, resource, genre)
