@@ -288,8 +288,6 @@ class StorageBrowser(ThumbableGridView):
         else:
             return False
             
-        self.__is_bulk_operation = True
-        
         
     def perform_bulk_action(self):
         """
@@ -501,7 +499,7 @@ class StorageBrowser(ThumbableGridView):
 
         @param folder: File object of the folder to load
         @param direction: One of C{GO_NEW}, C{GO_CHILD}, or C{GO_PARENT}
-        @param force_reload: whether to force reloading the folder
+        @param force_reload: whether to force fully reloading the folder
         """
 
         # are we just reloading the same folder?
@@ -576,9 +574,6 @@ class StorageBrowser(ThumbableGridView):
         if (not self.__prerender_handler):
             self.__prerender_handler = gobject.idle_add(self.__prerender_item,
                                                         time.time())
-
-        # now is a good time to collect garbage
-        #import gc; gc.collect()    
       
         
     def complete_current_folder(self):
@@ -606,10 +601,8 @@ class StorageBrowser(ThumbableGridView):
                 message = self.get_current_folder().message
                 if (message):
                     self.set_message(message)
-                elif (len(self.get_files()) > 0):
-                    self.set_message("")
                 else:
-                    self.set_message("Folder contains no media")
+                    self.set_message("")
                 
                 # mark folder as complete
                 self.__path_stack[-1][1] = _STATUS_OK
@@ -623,7 +616,7 @@ class StorageBrowser(ThumbableGridView):
             #end if
 
             # give visual feedback while loading the visible part of a folder
-            if (len(entries) == 12 or not f): #not f or len(entries) == 12):
+            if (len(entries) == 16 or not f): #not f or len(entries) == 12):
                 profile_now3 = time.time()
                 self.invalidate()
                 self.render()
@@ -635,10 +628,8 @@ class StorageBrowser(ThumbableGridView):
             # don't block UI while loading non-local folders
             #t = int((time.time() - open_time) * 10)
             if (time.time() > open_time + 3 and len(entries) % 2 == 0):
-                profile_now2 = time.time()
                 while (gtk.events_pending()):
                     gtk.main_iteration(False)
-                logging.profile(profile_now2, "[browser] processed UI events")
 
             if (not f):
                 # last item has been reached
@@ -690,10 +681,5 @@ class StorageBrowser(ThumbableGridView):
             self.set_hilight(idx)
         #self.invalidate_item(idx)
 
-        # prerender some of the items now, some later; this should
-        # distribute CPU load and disk IO
-        #if (l % 3 == 0):
-        #    item.render_at(None, 0, 0)
-        #else:
-        self.__items_to_prerender.append(item)
+        #self.__items_to_prerender.append(item)
 
