@@ -325,6 +325,14 @@ class GridView(ItemView):
         w, h = self.get_size()
         screen = self.get_screen()
 
+        """
+        screen.fill_area(x, y, w, h, theme.color_mb_background)
+        screen.draw_centered_text("Empty",
+                                  theme.font_mb_headline,
+                                  x, y + h / 2 - 30, w, 30,
+                                  theme.color_list_item_subtext)
+        """
+
         # render background and items
         if (self.__is_invalidated):
             self.__is_invalidated = False
