@@ -13,6 +13,8 @@ class MiniXML(object):
     This is useful when RAM is limited and we don't need a full-featured
     XML parser. Well, actually, it's almost full-featured by now, while still
     being tiny. :)
+    
+    @since: 0.96
     """
 
     def __init__(self, data, namespace = "", callback = None):
@@ -22,6 +24,7 @@ class MiniXML(object):
         the XML overrides the default namespace.
         If a callback is given, the callback is being called every time a
         node has been closed and is thus finished.
+        @since: 0.96
         
         @param data: string of XML data
         @param namespace: namespace URI
@@ -49,6 +52,7 @@ class MiniXML(object):
         """
         Returns the DOM representation of the XML tree. This does not
         adhere to the DOM specification.
+        @since: 0.96
         
         @return: DOM tree
         """
@@ -104,12 +108,14 @@ class MiniXML(object):
     def __read_text(self, begin, end):
 
         text = self.__data[begin:end]
-        text = text.replace("\n", " ")
+        text = text.replace("\n", " ") \
+                   .replace("\r", "")
         text = text.replace("&lt;", "<") \
                    .replace("&gt;", ">") \
                    .replace("&quot;", "\"") \
                    .replace("&apos;", "'") \
                    .replace("&amp;", "&")
+
         if (text.strip()):
             node = _Node("", {})
             node.set_value(text)
@@ -159,7 +165,7 @@ class MiniXML(object):
 
     def __lookup_namespace(self, ns):
     
-        for i in range(len(self.__ns_stack) - 1, 0, -1):
+        for i in range(len(self.__ns_stack) - 1, -1, -1):
             ns_table = self.__ns_stack[i]
             if (ns in ns_table):
                 return ns_table[ns]
@@ -170,9 +176,9 @@ class MiniXML(object):
 
     def __resolve_namespaces(self, tagname, attrs):
     
-        ns_table = {}
+        ns_table = {} #self.__ns_stack[0].copy()
         self.__ns_stack.append(ns_table)
-        
+                
         # check attrs for new namespace definitions
         for key, value in attrs.items():
             if (key.startswith("xmlns:")):
@@ -181,7 +187,7 @@ class MiniXML(object):
             elif (key == "xmlns"):
                 ns_table[""] = value
         #end for
-        
+
         # check tagname
         if (":" in tagname):
             ns_name, tagname = tagname.split(":")
@@ -278,6 +284,7 @@ class MiniXML(object):
 class _Node(object):
     """
     Class for representing a node in the DOM.
+    @since: 0.96
     """
 
     __slots__ = ["__tagname", "__attrs", "__children", "__value"]
@@ -286,6 +293,7 @@ class _Node(object):
         """
         Creates a new node with the given tagname and attributes.
         Pass an empty tagname for PCDATA nodes.
+        @since: 0.96
         """
 
         self.__tagname = tagname
@@ -297,6 +305,7 @@ class _Node(object):
     def add_child(self, child):
         """
         Adds a child node to this node.
+        @since: 0.96
         """
 
         self.__children.append(child)
@@ -305,6 +314,7 @@ class _Node(object):
         """
         Returns the node name. The name is prefixed by its namespace, if any.
         PCDATA nodes have an empty node name.
+        @since: 0.96
         """
 
         return self.__tagname
@@ -313,6 +323,7 @@ class _Node(object):
     def get_attrs(self):
         """
         Returns the attributes of this node as a dictionary.
+        @since: 0.96
         """
     
         return self.__attrs
@@ -322,6 +333,7 @@ class _Node(object):
         """
         Returns the value of the given attribute.
         Raises a KeyError if the attribute does not exist.
+        @since: 0.96
         """
         
         return self.__attrs[key]
@@ -330,6 +342,7 @@ class _Node(object):
     def get_children(self):
         """
         Returns a list of this node's child nodes.
+        @since: 0.96
         """
 
         return self.__children
@@ -340,6 +353,7 @@ class _Node(object):
         Convenience method for returning the child node with the given name,
         or the first child node if no name is given.
         Returns None if the child does not exist.
+        @since: 0.96
         """
     
         if (not name):
@@ -356,6 +370,7 @@ class _Node(object):
         Convenience function for returning the value of the PCDATA child
         node of this node.
         Returns "" if PCDATA is not available.
+        @since: 0.96
         """
         
         try:
@@ -372,6 +387,7 @@ class _Node(object):
     def set_value(self, value):
         """
         Sets the PCDATA value.
+        @since: 0.96
         """
         self.__value = value
 
@@ -379,6 +395,7 @@ class _Node(object):
     def get_value(self):
         """
         Returns the PCDATA value.
+        @since: 0.96
         """
 
         return self.__value
@@ -387,6 +404,7 @@ class _Node(object):
     def _dump(self, indent = 0):
         """
         Recursively dumps the subtree beginning at this node.
+        @since: 0.96
         """
         
         out = ""
